Web   ·   Wiki   ·   Activities   ·   Blog   ·   Lists   ·   Chat   ·   Meeting   ·   Bugs   ·   Git   ·   Translate   ·   Archive   ·   People   ·   Donate
summaryrefslogtreecommitdiffstats
path: root/shell/ev-window.c
diff options
context:
space:
mode:
Diffstat (limited to 'shell/ev-window.c')
-rw-r--r--shell/ev-window.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/shell/ev-window.c b/shell/ev-window.c
index 65b8812..102e56c 100644
--- a/shell/ev-window.c
+++ b/shell/ev-window.c
@@ -2873,8 +2873,8 @@ ev_window_init (EvWindow *ev_window)
G_CALLBACK (find_bar_search_changed_cb),
ev_window);
- /* Give focus to the scrolled window */
- gtk_widget_grab_focus (ev_window->priv->scrolled_window);
+ /* Give focus to the document view */
+ gtk_widget_grab_focus (ev_window->priv->view);
/* Drag and Drop */
gtk_drag_dest_unset (GTK_WIDGET (ev_window));